==> aoe-djin-0.2.1.crate: aoe-djin-0.2.1/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file. See [conventional commits](https://www.conventionalcommits.org/) for commit guidelines.

- - -
## 0.2.1 - 2021-07-25


### Bug Fixes

[178c00](https://github.com/scout-gg/djin/commit/178c00e8b3db136344fce8dbe672a47853376038) - fix packaging release stage in cog.toml - [oknozor](https://github.com/oknozor)

[bcf643](https://github.com/scout-gg/djin/commit/bcf6436d416ca5177a8d341a9d5d83e096552b1f) - make all fields public - [oknozor](https://github.com/oknozor)

[b7d6e5](https://github.com/scout-gg/djin/commit/b7d6e526739c427927cda36651e341ebab396f25) - remove useless print and add example - [oknozor](https://github.com/oknozor)


### Documentation

[8c48a7](https://github.com/scout-gg/djin/commit/8c48a74f21cb38b5f6e770cd4ec2b2e392aec0e7) - add readme badges - [oknozor](https://github.com/oknozor)

[761085](https://github.com/scout-gg/djin/commit/761085110014e895e7290fa46242cc2dc94e4fa2) - add datfile example - [oknozor](https://github.com/oknozor)


- - -
## 0.2.0 - 2021-07-24


### Features

[ded58b](https://github.com/scout-gg/djin/commit/ded58b5845e86e93067422903b7497525cdd16b1) - implement tech tree, datfile is now complete - [oknozor](https://github.com/oknozor)


- - -
## 0.1.0 - 2021-07-24


### Documentation

[7988d7](https://github.com/scout-gg/djin/commit/7988d7ae7a78041130556d8277a03f6253e2f04e) - add microsoft Game Content Usage Rules - [oknozor](https://github.com/oknozor)


### Features

[c615e3](https://github.com/scout-gg/djin/commit/c615e3f41a09c753e8ba7d06b750ce1cc7c2fea3) - add tech and use enum for unit id - [oknozor](https://github.com/oknozor)

[05b606](https://github.com/scout-gg/djin/commit/05b6066985cf95ee9b0a510d2035d4ccf8fe9f45) - parse civilizations - [oknozor](https://github.com/oknozor)

[26bd21](https://github.com/scout-gg/djin/commit/26bd21aabc89650ddf7e14e8dc184606b8deda5c) - update protocol to use length pointer attr - [oknozor](https://github.com/oknozor)

[200e0e](https://github.com/scout-gg/djin/commit/200e0e77dc50f0036f7dfa9ae02aecf065294f88) - parse terrains - [oknozor](https://github.com/oknozor)

[edb0b6](https://github.com/scout-gg/djin/commit/edb0b68b35054df1dc33132580edc1819d6643db) - parse sprites - [oknozor](https://github.com/oknozor)

[9c3da3](https://github.com/scout-gg/djin/commit/9c3da37c8e76f32465bd6d1caddbd55dccab0349) - implement sound, color, terrain and game version - [oknozor](https://github.com/oknozor)


### Miscellaneous Chores

[44c300](https://github.com/scout-gg/djin/commit/44c300618498cae99b198c926c4a9502f7e909de) - fmt all - [oknozor](https://github.com/oknozor)

[7ddd1f](https://github.com/scout-gg/djin/commit/7ddd1fc1d13d3ce0a72e89934fcdbf5c9af613b6) - use protocol fork - [oknozor](https://github.com/oknozor)

[943d6c](https://github.com/scout-gg/djin/commit/943d6ca6c15f3ec0d05443d033d0e6560a0f53f8) - fix auto release - [oknozor](https://github.com/oknozor)

[045b22](https://github.com/scout-gg/djin/commit/045b22a7871ba90d50e0f1e5503689ee75811dcb) - add license - [oknozor](https://github.com/oknozor)

[ab3d96](https://github.com/scout-gg/djin/commit/ab3d96c46bb9fa83ebd63046068f727a6ecfcea6) - expose dat module - [oknozor](https://github.com/oknozor)

[9d52f1](https://github.com/scout-gg/djin/commit/9d52f11a921690d3af1fdeba7e38074801b347cd) - add CI configuration - [oknozor](https://github.com/oknozor)

[2c8a9f](https://github.com/scout-gg/djin/commit/2c8a9f93a9b4afc9b730b9cddde9faa0b291715e) - clippy lints and fmt * - [oknozor](https://github.com/oknozor)


### Bug Fixes

[5ac555](https://github.com/scout-gg/djin/commit/5ac555e87e1c11181481caf45e861af21517048f) - fix sound table - [oknozor](https://github.com/oknozor)


- - -

This changelog was generated by [cocogitto](https://github.com/oknozor/cocogitto).

==> aoe-djin-0.3.0.crate: aoe-djin-0.3.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file. See [conventional commits](https://www.conventionalcommits.org/) for commit guidelines.

- - -
## 0.3.0 - 2021-07-25


### Refactoring

[bc790a](https://github.com/scout-gg/djin/commit/bc790ae47694930b1420d27967be6b062f490920) - rename top level Datfile fields to avoid repetition - [oknozor](https://github.com/oknozor)


### Features

[4a8298](https://github.com/scout-gg/djin/commit/4a8298fece89f9b4010d31ea456c732690fbf9bf) - add tech tree status - [oknozor](https://github.com/oknozor)

[57edd1](https://github.com/scout-gg/djin/commit/57edd1d1e6d3369da7601f929be337d3ac24f55e) - use enum for resource usage type and resource usage trigger - [oknozor](https://github.com/oknozor)


- - -
## 0.2.1 - 2021-07-25


### Bug Fixes

[178c00](https://github.com/scout-gg/djin/commit/178c00e8b3db136344fce8dbe672a47853376038) - fix packaging release stage in cog.toml - [oknozor](https://github.com/oknozor)

[bcf643](https://github.com/scout-gg/djin/commit/bcf6436d416ca5177a8d341a9d5d83e096552b1f) - make all fields public - [oknozor](https://github.com/oknozor)

[b7d6e5](https://github.com/scout-gg/djin/commit/b7d6e526739c427927cda36651e341ebab396f25) - remove useless print and add example - [oknozor](https://github.com/oknozor)


### Documentation

[8c48a7](https://github.com/scout-gg/djin/commit/8c48a74f21cb38b5f6e770cd4ec2b2e392aec0e7) - add readme badges - [oknozor](https://github.com/oknozor)

[761085](https://github.com/scout-gg/djin/commit/761085110014e895e7290fa46242cc2dc94e4fa2) - add datfile example - [oknozor](https://github.com/oknozor)


- - -
## 0.2.0 - 2021-07-24


### Features

[ded58b](https://github.com/scout-gg/djin/commit/ded58b5845e86e93067422903b7497525cdd16b1) - implement tech tree, datfile is now complete - [oknozor](https://github.com/oknozor)


- - -
## 0.1.0 - 2021-07-24


### Documentation

[7988d7](https://github.com/scout-gg/djin/commit/7988d7ae7a78041130556d8277a03f6253e2f04e) - add microsoft Game Content Usage Rules - [oknozor](https://github.com/oknozor)


### Features

[c615e3](https://github.com/scout-gg/djin/commit/c615e3f41a09c753e8ba7d06b750ce1cc7c2fea3) - add tech and use enum for unit id - [oknozor](https://github.com/oknozor)

[05b606](https://github.com/scout-gg/djin/commit/05b6066985cf95ee9b0a510d2035d4ccf8fe9f45) - parse civilizations - [oknozor](https://github.com/oknozor)

[26bd21](https://github.com/scout-gg/djin/commit/26bd21aabc89650ddf7e14e8dc184606b8deda5c) - update protocol to use length pointer attr - [oknozor](https://github.com/oknozor)

[200e0e](https://github.com/scout-gg/djin/commit/200e0e77dc50f0036f7dfa9ae02aecf065294f88) - parse terrains - [oknozor](https://github.com/oknozor)

[edb0b6](https://github.com/scout-gg/djin/commit/edb0b68b35054df1dc33132580edc1819d6643db) - parse sprites - [oknozor](https://github.com/oknozor)

[9c3da3](https://github.com/scout-gg/djin/commit/9c3da37c8e76f32465bd6d1caddbd55dccab0349) - implement sound, color, terrain and game version - [oknozor](https://github.com/oknozor)


### Miscellaneous Chores

[44c300](https://github.com/scout-gg/djin/commit/44c300618498cae99b198c926c4a9502f7e909de) - fmt all - [oknozor](https://github.com/oknozor)

[7ddd1f](https://github.com/scout-gg/djin/commit/7ddd1fc1d13d3ce0a72e89934fcdbf5c9af613b6) - use protocol fork - [oknozor](https://github.com/oknozor)

[943d6c](https://github.com/scout-gg/djin/commit/943d6ca6c15f3ec0d05443d033d0e6560a0f53f8) - fix auto release - [oknozor](https://github.com/oknozor)

[045b22](https://github.com/scout-gg/djin/commit/045b22a7871ba90d50e0f1e5503689ee75811dcb) - add license - [oknozor](https://github.com/oknozor)

[ab3d96](https://github.com/scout-gg/djin/commit/ab3d96c46bb9fa83ebd63046068f727a6ecfcea6) - expose dat module - [oknozor](https://github.com/oknozor)

[9d52f1](https://github.com/scout-gg/djin/commit/9d52f11a921690d3af1fdeba7e38074801b347cd) - add CI configuration - [oknozor](https://github.com/oknozor)

[2c8a9f](https://github.com/scout-gg/djin/commit/2c8a9f93a9b4afc9b730b9cddde9faa0b291715e) - clippy lints and fmt * - [oknozor](https://github.com/oknozor)


### Bug Fixes

[5ac555](https://github.com/scout-gg/djin/commit/5ac555e87e1c11181481caf45e861af21517048f) - fix sound table - [oknozor](https://github.com/oknozor)


- - -

This changelog was generated by [cocogitto](https://github.com/oknozor/cocogitto).
